#[non_exhaustive]pub enum ArtifactOutputSupport {
Stored,
Derived,
Approximated,
Unsupported,
Unlisted,
}Expand description
Describes how a high-level artifact output is represented by the profile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Stored
The output is stored directly in the artifact payload.
Derived
The output is reconstructed deterministically from stored data.
Approximated
The output is approximated numerically from neighboring decoded data.
Unsupported
The output is explicitly unsupported by the profile.
Unlisted
The output is neither stored nor explicitly declared by the profile.
Implementations